==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/order/ObjectFactory.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.order;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlElementDecl;
import javax.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.order package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _FindOrdersResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrdersResponse");
    private final static QName _UpdateOrder_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "updateOrder");
    private final static QName _FindOrdersBySAndANResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrdersBySAndANResponse");
    private final static QName _BillingException_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "BillingException");
    private final static QName _UpdateOrderResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "updateOrderResponse");
    private final static QName _FindOrders_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrders");
    private final static QName _FindActiveOrders_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrders");
    private final static QName _CreateOrder_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrder");
    private final static QName _FindActiveOrdersBySSAndANResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrdersBySSAndANResponse");
    private final static QName _FindOrdersBySAndAN_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrdersBySAndAN");
    private final static QName _FindActiveOrdersResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrdersResponse");
    private final static QName _CreateOrderByOffering_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrderByOffering");
    private final static QName _CreateOrderResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrderResponse");
    private final static QName _FindActiveOrdersBySSAndAN_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrdersBySSAndAN");
    private final static QName _CreateOrderByOfferingResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrderByOfferingResponse");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.order
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Service }
     * 
     */
    public Service createService() {
        return new Service();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters }
     * 
     */
    public Service.AdditionalParameters createServiceAdditionalParameters() {
        return new Service.AdditionalParameters();
    }

    /**
     * Create an instance of {@link UpdateOrder }
     * 
     */
    public UpdateOrder createUpdateOrder() {
        return new UpdateOrder();
    }

    /**
     * Create an instance of {@link FindOrdersBySAndANResponse }
     * 
     */
    public FindOrdersBySAndANResponse createFindOrdersBySAndANResponse() {
        return new FindOrdersBySAndANResponse();
    }

    /**
     * Create an instance of {@link FindOrdersResponse }
     * 
     */
    public FindOrdersResponse createFindOrdersResponse() {
        return new FindOrdersResponse();
    }

    /**
     * Create an instance of {@link BillingException }
     * 
     */
    public BillingException createBillingException() {
        return new BillingException();
    }

    /**
     * Create an instance of {@link UpdateOrderResponse }
     * 
     */
    public UpdateOrderResponse createUpdateOrderResponse() {
        return new UpdateOrderResponse();
    }

    /**
     * Create an instance of {@link FindOrders }
     * 
     */
    public FindOrders createFindOrders() {
        return new FindOrders();
    }

    /**
     * Create an instance of {@link FindActiveOrdersBySSAndANResponse }
     * 
     */
    public FindActiveOrdersBySSAndANResponse createFindActiveOrdersBySSAndANResponse() {
        return new FindActiveOrdersBySSAndANResponse();
    }

    /**
     * Create an instance of {@link FindOrdersBySAndAN }
     * 
     */
    public FindOrdersBySAndAN createFindOrdersBySAndAN() {
        return new FindOrdersBySAndAN();
    }

    /**
     * Create an instance of {@link FindActiveOrders }
     * 
     */
    public FindActiveOrders createFindActiveOrders() {
        return new FindActiveOrders();
    }

    /**
     * Create an instance of {@link CreateOrder }
     * 
     */
    public CreateOrder createCreateOrder() {
        return new CreateOrder();
    }

    /**
     * Create an instance of {@link CreateOrderResponse }
     * 
     */
    public CreateOrderResponse createCreateOrderResponse() {
        return new CreateOrderResponse();
    }

    /**
     * Create an instance of {@link FindActiveOrdersBySSAndAN }
     * 
     */
    public FindActiveOrdersBySSAndAN createFindActiveOrdersBySSAndAN() {
        return new FindActiveOrdersBySSAndAN();
    }

    /**
     * Create an instance of {@link CreateOrderByOffering }
     * 
     */
    public CreateOrderByOffering createCreateOrderByOffering() {
        return new CreateOrderByOffering();
    }

    /**
     * Create an instance of {@link FindActiveOrdersResponse }
     * 
     */
    public FindActiveOrdersResponse createFindActiveOrdersResponse() {
        return new FindActiveOrdersResponse();
    }

    /**
     * Create an instance of {@link CreateOrderByOfferingResponse }
     * 
     */
    public CreateOrderByOfferingResponse createCreateOrderByOfferingResponse() {
        return new CreateOrderByOfferingResponse();
    }

    /**
     * Create an instance of {@link OrderType }
     * 
     */
    public OrderType createOrderType() {
        return new OrderType();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link Interaction }
     * 
     */
    public Interaction createInteraction() {
        return new Interaction();
    }

    /**
     * Create an instance of {@link ServiceOffering }
     * 
     */
    public ServiceOffering createServiceOffering() {
        return new ServiceOffering();
    }

    /**
     * Create an instance of {@link TimeFrame }
     * 
     */
    public TimeFrame createTimeFrame() {
        return new TimeFrame();
    }

    /**
     * Create an instance of {@link ServiceSpecification }
     * 
     */
    public ServiceSpecification createServiceSpecification() {
        return new ServiceSpecification();
    }

    /**
     * Create an instance of {@link Price }
     * 
     */
    public Price createPrice() {
        return new Price();
    }

    /**
     * Create an instance of {@link ServiceOrder }
     * 
     */
    public ServiceOrder createServiceOrder() {
        return new ServiceOrder();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters.Entry }
     * 
     */
    public Service.AdditionalParameters.Entry createServiceAdditionalParametersEntry() {
        return new Service.AdditionalParameters.Entry();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrdersResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrdersResponse")
    public JAXBElement<FindOrdersResponse> createFindOrdersResponse(FindOrdersResponse value) {
        return new JAXBElement<FindOrdersResponse>(_FindOrdersResponse_QNAME, FindOrdersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UpdateOrder }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "updateOrder")
    public JAXBElement<UpdateOrder> createUpdateOrder(UpdateOrder value) {
        return new JAXBElement<UpdateOrder>(_UpdateOrder_QNAME, UpdateOrder.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrdersBySAndANResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrdersBySAndANResponse")
    public JAXBElement<FindOrdersBySAndANResponse> createFindOrdersBySAndANResponse(FindOrdersBySAndANResponse value) {
        return new JAXBElement<FindOrdersBySAndANResponse>(_FindOrdersBySAndANResponse_QNAME, FindOrdersBySAndANResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BillingException }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "BillingException")
    public JAXBElement<BillingException> createBillingException(BillingException value) {
        return new JAXBElement<BillingException>(_BillingException_QNAME, BillingException.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UpdateOrderResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "updateOrderResponse")
    public JAXBElement<UpdateOrderResponse> createUpdateOrderResponse(UpdateOrderResponse value) {
        return new JAXBElement<UpdateOrderResponse>(_UpdateOrderResponse_QNAME, UpdateOrderResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrders }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrders")
    public JAXBElement<FindOrders> createFindOrders(FindOrders value) {
        return new JAXBElement<FindOrders>(_FindOrders_QNAME, FindOrders.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrders }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrders")
    public JAXBElement<FindActiveOrders> createFindActiveOrders(FindActiveOrders value) {
        return new JAXBElement<FindActiveOrders>(_FindActiveOrders_QNAME, FindActiveOrders.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrder }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrder")
    public JAXBElement<CreateOrder> createCreateOrder(CreateOrder value) {
        return new JAXBElement<CreateOrder>(_CreateOrder_QNAME, CreateOrder.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrdersBySSAndANResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrdersBySSAndANResponse")
    public JAXBElement<FindActiveOrdersBySSAndANResponse> createFindActiveOrdersBySSAndANResponse(FindActiveOrdersBySSAndANResponse value) {
        return new JAXBElement<FindActiveOrdersBySSAndANResponse>(_FindActiveOrdersBySSAndANResponse_QNAME, FindActiveOrdersBySSAndANResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrdersBySAndAN }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrdersBySAndAN")
    public JAXBElement<FindOrdersBySAndAN> createFindOrdersBySAndAN(FindOrdersBySAndAN value) {
        return new JAXBElement<FindOrdersBySAndAN>(_FindOrdersBySAndAN_QNAME, FindOrdersBySAndAN.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrdersResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrdersResponse")
    public JAXBElement<FindActiveOrdersResponse> createFindActiveOrdersResponse(FindActiveOrdersResponse value) {
        return new JAXBElement<FindActiveOrdersResponse>(_FindActiveOrdersResponse_QNAME, FindActiveOrdersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrderByOffering }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrderByOffering")
    public JAXBElement<CreateOrderByOffering> createCreateOrderByOffering(CreateOrderByOffering value) {
        return new JAXBElement<CreateOrderByOffering>(_CreateOrderByOffering_QNAME, CreateOrderByOffering.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrderResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrderResponse")
    public JAXBElement<CreateOrderResponse> createCreateOrderResponse(CreateOrderResponse value) {
        return new JAXBElement<CreateOrderResponse>(_CreateOrderResponse_QNAME, CreateOrderResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrdersBySSAndAN }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrdersBySSAndAN")
    public JAXBElement<FindActiveOrdersBySSAndAN> createFindActiveOrdersBySSAndAN(FindActiveOrdersBySSAndAN value) {
        return new JAXBElement<FindActiveOrdersBySSAndAN>(_FindActiveOrdersBySSAndAN_QNAME, FindActiveOrdersBySSAndAN.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrderByOfferingResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrderByOfferingResponse")
    public JAXBElement<CreateOrderByOfferingResponse> createCreateOrderByOfferingResponse(CreateOrderByOfferingResponse value) {
        return new JAXBElement<CreateOrderByOfferingResponse>(_CreateOrderByOfferingResponse_QNAME, CreateOrderByOfferingResponse.class, null, value);
    }

}

==> tv_9.2310-2412091114.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/order/ObjectFactory.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.order;

import jakarta.xml.bind.JAXBElement;
import jakarta.xml.bind.annotation.XmlElementDecl;
import jakarta.xml.bind.annotation.XmlRegistry;
import javax.xml.namespace.QName;


/**
 * This object contains factory methods for each 
 * Java content interface and Java element interface 
 * generated in the ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.order package. 
 * <p>An ObjectFactory allows you to programatically 
 * construct new instances of the Java representation 
 * for XML content. The Java representation of XML 
 * content can consist of schema derived interfaces 
 * and classes representing the binding of schema 
 * type definitions, element declarations and model 
 * groups.  Factory methods for each of these are 
 * provided in this class.
 * 
 */
@XmlRegistry
public class ObjectFactory {

    private final static QName _FindOrdersResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrdersResponse");
    private final static QName _UpdateOrder_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "updateOrder");
    private final static QName _FindOrdersBySAndANResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrdersBySAndANResponse");
    private final static QName _BillingException_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "BillingException");
    private final static QName _UpdateOrderResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "updateOrderResponse");
    private final static QName _FindOrders_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrders");
    private final static QName _FindActiveOrders_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrders");
    private final static QName _CreateOrder_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrder");
    private final static QName _FindActiveOrdersBySSAndANResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrdersBySSAndANResponse");
    private final static QName _FindOrdersBySAndAN_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findOrdersBySAndAN");
    private final static QName _FindActiveOrdersResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrdersResponse");
    private final static QName _CreateOrderByOffering_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrderByOffering");
    private final static QName _CreateOrderResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrderResponse");
    private final static QName _FindActiveOrdersBySSAndAN_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "findActiveOrdersBySSAndAN");
    private final static QName _CreateOrderByOfferingResponse_QNAME = new QName("http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", "createOrderByOfferingResponse");

    /**
     * Create a new ObjectFactory that can be used to create new instances of schema derived classes for package: ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.order
     * 
     */
    public ObjectFactory() {
    }

    /**
     * Create an instance of {@link Service }
     * 
     */
    public Service createService() {
        return new Service();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters }
     * 
     */
    public Service.AdditionalParameters createServiceAdditionalParameters() {
        return new Service.AdditionalParameters();
    }

    /**
     * Create an instance of {@link UpdateOrder }
     * 
     */
    public UpdateOrder createUpdateOrder() {
        return new UpdateOrder();
    }

    /**
     * Create an instance of {@link FindOrdersBySAndANResponse }
     * 
     */
    public FindOrdersBySAndANResponse createFindOrdersBySAndANResponse() {
        return new FindOrdersBySAndANResponse();
    }

    /**
     * Create an instance of {@link FindOrdersResponse }
     * 
     */
    public FindOrdersResponse createFindOrdersResponse() {
        return new FindOrdersResponse();
    }

    /**
     * Create an instance of {@link BillingException }
     * 
     */
    public BillingException createBillingException() {
        return new BillingException();
    }

    /**
     * Create an instance of {@link UpdateOrderResponse }
     * 
     */
    public UpdateOrderResponse createUpdateOrderResponse() {
        return new UpdateOrderResponse();
    }

    /**
     * Create an instance of {@link FindOrders }
     * 
     */
    public FindOrders createFindOrders() {
        return new FindOrders();
    }

    /**
     * Create an instance of {@link FindActiveOrdersBySSAndANResponse }
     * 
     */
    public FindActiveOrdersBySSAndANResponse createFindActiveOrdersBySSAndANResponse() {
        return new FindActiveOrdersBySSAndANResponse();
    }

    /**
     * Create an instance of {@link FindOrdersBySAndAN }
     * 
     */
    public FindOrdersBySAndAN createFindOrdersBySAndAN() {
        return new FindOrdersBySAndAN();
    }

    /**
     * Create an instance of {@link FindActiveOrders }
     * 
     */
    public FindActiveOrders createFindActiveOrders() {
        return new FindActiveOrders();
    }

    /**
     * Create an instance of {@link CreateOrder }
     * 
     */
    public CreateOrder createCreateOrder() {
        return new CreateOrder();
    }

    /**
     * Create an instance of {@link CreateOrderResponse }
     * 
     */
    public CreateOrderResponse createCreateOrderResponse() {
        return new CreateOrderResponse();
    }

    /**
     * Create an instance of {@link FindActiveOrdersBySSAndAN }
     * 
     */
    public FindActiveOrdersBySSAndAN createFindActiveOrdersBySSAndAN() {
        return new FindActiveOrdersBySSAndAN();
    }

    /**
     * Create an instance of {@link CreateOrderByOffering }
     * 
     */
    public CreateOrderByOffering createCreateOrderByOffering() {
        return new CreateOrderByOffering();
    }

    /**
     * Create an instance of {@link FindActiveOrdersResponse }
     * 
     */
    public FindActiveOrdersResponse createFindActiveOrdersResponse() {
        return new FindActiveOrdersResponse();
    }

    /**
     * Create an instance of {@link CreateOrderByOfferingResponse }
     * 
     */
    public CreateOrderByOfferingResponse createCreateOrderByOfferingResponse() {
        return new CreateOrderByOfferingResponse();
    }

    /**
     * Create an instance of {@link OrderType }
     * 
     */
    public OrderType createOrderType() {
        return new OrderType();
    }

    /**
     * Create an instance of {@link Resource }
     * 
     */
    public Resource createResource() {
        return new Resource();
    }

    /**
     * Create an instance of {@link Interaction }
     * 
     */
    public Interaction createInteraction() {
        return new Interaction();
    }

    /**
     * Create an instance of {@link ServiceOffering }
     * 
     */
    public ServiceOffering createServiceOffering() {
        return new ServiceOffering();
    }

    /**
     * Create an instance of {@link TimeFrame }
     * 
     */
    public TimeFrame createTimeFrame() {
        return new TimeFrame();
    }

    /**
     * Create an instance of {@link ServiceSpecification }
     * 
     */
    public ServiceSpecification createServiceSpecification() {
        return new ServiceSpecification();
    }

    /**
     * Create an instance of {@link Price }
     * 
     */
    public Price createPrice() {
        return new Price();
    }

    /**
     * Create an instance of {@link ServiceOrder }
     * 
     */
    public ServiceOrder createServiceOrder() {
        return new ServiceOrder();
    }

    /**
     * Create an instance of {@link Service.AdditionalParameters.Entry }
     * 
     */
    public Service.AdditionalParameters.Entry createServiceAdditionalParametersEntry() {
        return new Service.AdditionalParameters.Entry();
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrdersResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrdersResponse")
    public JAXBElement<FindOrdersResponse> createFindOrdersResponse(FindOrdersResponse value) {
        return new JAXBElement<FindOrdersResponse>(_FindOrdersResponse_QNAME, FindOrdersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UpdateOrder }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "updateOrder")
    public JAXBElement<UpdateOrder> createUpdateOrder(UpdateOrder value) {
        return new JAXBElement<UpdateOrder>(_UpdateOrder_QNAME, UpdateOrder.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrdersBySAndANResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrdersBySAndANResponse")
    public JAXBElement<FindOrdersBySAndANResponse> createFindOrdersBySAndANResponse(FindOrdersBySAndANResponse value) {
        return new JAXBElement<FindOrdersBySAndANResponse>(_FindOrdersBySAndANResponse_QNAME, FindOrdersBySAndANResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link BillingException }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "BillingException")
    public JAXBElement<BillingException> createBillingException(BillingException value) {
        return new JAXBElement<BillingException>(_BillingException_QNAME, BillingException.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link UpdateOrderResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "updateOrderResponse")
    public JAXBElement<UpdateOrderResponse> createUpdateOrderResponse(UpdateOrderResponse value) {
        return new JAXBElement<UpdateOrderResponse>(_UpdateOrderResponse_QNAME, UpdateOrderResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrders }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrders")
    public JAXBElement<FindOrders> createFindOrders(FindOrders value) {
        return new JAXBElement<FindOrders>(_FindOrders_QNAME, FindOrders.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrders }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrders")
    public JAXBElement<FindActiveOrders> createFindActiveOrders(FindActiveOrders value) {
        return new JAXBElement<FindActiveOrders>(_FindActiveOrders_QNAME, FindActiveOrders.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrder }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrder")
    public JAXBElement<CreateOrder> createCreateOrder(CreateOrder value) {
        return new JAXBElement<CreateOrder>(_CreateOrder_QNAME, CreateOrder.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrdersBySSAndANResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrdersBySSAndANResponse")
    public JAXBElement<FindActiveOrdersBySSAndANResponse> createFindActiveOrdersBySSAndANResponse(FindActiveOrdersBySSAndANResponse value) {
        return new JAXBElement<FindActiveOrdersBySSAndANResponse>(_FindActiveOrdersBySSAndANResponse_QNAME, FindActiveOrdersBySSAndANResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindOrdersBySAndAN }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findOrdersBySAndAN")
    public JAXBElement<FindOrdersBySAndAN> createFindOrdersBySAndAN(FindOrdersBySAndAN value) {
        return new JAXBElement<FindOrdersBySAndAN>(_FindOrdersBySAndAN_QNAME, FindOrdersBySAndAN.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrdersResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrdersResponse")
    public JAXBElement<FindActiveOrdersResponse> createFindActiveOrdersResponse(FindActiveOrdersResponse value) {
        return new JAXBElement<FindActiveOrdersResponse>(_FindActiveOrdersResponse_QNAME, FindActiveOrdersResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrderByOffering }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrderByOffering")
    public JAXBElement<CreateOrderByOffering> createCreateOrderByOffering(CreateOrderByOffering value) {
        return new JAXBElement<CreateOrderByOffering>(_CreateOrderByOffering_QNAME, CreateOrderByOffering.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrderResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrderResponse")
    public JAXBElement<CreateOrderResponse> createCreateOrderResponse(CreateOrderResponse value) {
        return new JAXBElement<CreateOrderResponse>(_CreateOrderResponse_QNAME, CreateOrderResponse.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link FindActiveOrdersBySSAndAN }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "findActiveOrdersBySSAndAN")
    public JAXBElement<FindActiveOrdersBySSAndAN> createFindActiveOrdersBySSAndAN(FindActiveOrdersBySSAndAN value) {
        return new JAXBElement<FindActiveOrdersBySSAndAN>(_FindActiveOrdersBySSAndAN_QNAME, FindActiveOrdersBySSAndAN.class, null, value);
    }

    /**
     * Create an instance of {@link JAXBElement }{@code <}{@link CreateOrderByOfferingResponse }{@code >}}
     * 
     */
    @XmlElementDecl(namespace = "http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/", name = "createOrderByOfferingResponse")
    public JAXBElement<CreateOrderByOfferingResponse> createCreateOrderByOfferingResponse(CreateOrderByOfferingResponse value) {
        return new JAXBElement<CreateOrderByOfferingResponse>(_CreateOrderByOfferingResponse_QNAME, CreateOrderByOfferingResponse.class, null, value);
    }

}
